import { Placement } from '@floating-ui/dom';
import { GdsElement } from '../../gds-element';
/**
 * @element gds-coachmark
 * A tooltip container with a slot and an arrow pointing towards the targeted element
 * depending on the preferred placement,
 * the coachmark is hidden/disabled when the element is overlapped or out of viewport.
 *
 * @slot body - placeholder for the content of the tooltip.
 *
 * @event tooltipClosed - dispatched when the tooltip is closed
 */
export declare class GdsCoachmark extends GdsElement {
    #private;
    static styles: import("lit").CSSResult;
    /**
     * @internal
     */
    static shadowRootOptions: ShadowRootInit;
    /**
     *Tracks the visibility of the tooltip (readonly)
     */
    _isVisible: boolean;
    /**
     *Used to prevent closing the tooltip if it's not visible (readonly)
     */
    _preventClose: boolean;
    /**
     * The placement of the popover relative to the trigger.
     * Accepts any of the placements supported by Floating UI.
     */
    placement: Placement;
    /**
     * The coachmark will be hidden when overlapped by the list of provided elements (selectors).
     */
    overlappedBy: string[];
    /**
     * List of selectors pointing to the targeted element. Ex. for a target inside a ShadowDOM: ["some-component", "shadowRoot", "target-element"].
     */
    target: string[];
    connectedCallback(): void;
    disconnectedCallback(): void;
    firstUpdated(): void;
    setPreventClose(preventClose: boolean): void;
    render(): any;
}
